@@ -14,11 +14,7 @@ ALT_CYRILLIC = {
     u'я': u'ya',   # instead of 'ia'
 }
 
-#UNWANTED_CHARS_RE = re.compile(r'[^A-Za-z0-9]+')
-UNWANTED_CHARS = re.compile(u'[_\W]+', re.UNICODE)  # all except letters and digits
-SEPARATOR = u'-'
-
-
+# Python 3 support
 if sys.version_info > (3, 0):
     unicode = str
 
@@ -53,13 +49,27 @@ def translate(text):
     return text
 
 
-def sanitize(text):
-    text = text.replace("'", '').strip()  # remove '
-    words = filter(None, UNWANTED_CHARS.split(text))  # split by unwanted characters
-    return words
+def get_sanitize(safe_chars):
+
+    apostrophe_is_not_safe = "'" not in safe_chars
+
+    if '_' in safe_chars:
+        unwanted_chars_pattern_template = u'{unwanted_char_pattern}+'
+    else:
+        unwanted_chars_pattern_template = u'(?:{unwanted_char_pattern}|_)+'
+    unwanted_char_pattern = u'[^\w{safe_chars}]'.format(safe_chars=re.escape(safe_chars))
+    unwanted_chars_pattern = unwanted_chars_pattern_template.format(unwanted_char_pattern=unwanted_char_pattern)
+    unwanted_chars_re = re.compile(unwanted_chars_pattern, re.UNICODE)
+
+    def sanitize(text):
+        if apostrophe_is_not_safe:
+            text = text.replace("'", '').strip()  # remove '
+        return filter(None, unwanted_chars_re.split(text))  # split by unwanted characters
+
+    return sanitize
 
 
-def join_words(words, max_length=None, separator=SEPARATOR):
+def join_words(words, separator, max_length=None):
 
     if not max_length:
         return separator.join(words)
@@ -73,9 +83,11 @@ def join_words(words, max_length=None, separator=SEPARATOR):
     return text[:max_length]
 
 
-def get_slugify(pretranslate=None, translate=translate, max_length=None, separator=SEPARATOR, capitalize=False):
+def get_slugify(pretranslate=None, translate=translate, safe_chars='',
+                max_length=None, separator=u'-', capitalize=False):
 
     pretranslate = get_pretranslate(pretranslate)
+    sanitize = get_sanitize(safe_chars)
 
     def slugify(text, max_length=max_length, separator=separator, capitalize=capitalize):
         if not isinstance(text, unicode):
@@ -86,7 +98,7 @@ def get_slugify(pretranslate=None, translate=translate, max_length=None, separat
         if translate:
             text = translate(text)
         words = sanitize(text)
-        text = join_words(words, max_length, separator)
+        text = join_words(words, separator, max_length)
 
         if capitalize:
             text = text[0].upper() + text[1:]
@@ -98,4 +110,4 @@ def get_slugify(pretranslate=None, translate=translate, max_length=None, separat
 
 slugify = get_slugify()
 slugify_ru = get_slugify(pretranslate=ALT_CYRILLIC)
-slugify_unicode = get_slugify(translate=None)
\ No newline at end of file
+slugify_unicode = get_slugify(translate=None)
